diff --git a/doc/manuals/libabigail-concepts.rst b/doc/manuals/libabigail-concepts.rst
index f8b5f105..f850252b 100644
--- a/doc/manuals/libabigail-concepts.rst
+++ b/doc/manuals/libabigail-concepts.rst
@@ -353,6 +353,31 @@ The potential properties of this sections are listed below:
       changed_enumerators = LAST_ENUMERATORS0, LAST_ENUMERATOR1
 
 
+.. _suppr_changed_enumerators_regexp_label:
+
+* ``changed_enumerators_regexp``
+
+  Usage:
+
+    ``changed_enumerators_regexp`` ``=`` <list-of-enumerator-regular-expressions>
+
+  Suppresses change reports involving changes in the value of
+  enumerators of a given enum type.  This property is applied if the
+  ``type_kind`` property is set to the value ``enum``, at least.  The
+  value of the ``changed_enumerators_regexp`` property is a
+  comma-separated list of regular expressions that should match the
+  names of the enumerators that the user expects to change.  For
+  instance: ::
+
+      changed_enumerators_regexp = .*_MAX$, .*_LAST$, .*_NUM$, .*_NBITS$
+
+  In the example above, change reports to any enumerator which name
+  ends with _MAX, _LAST, _NUM or _NBITS will be suppressed.
+
+  Note that for this property to be applied to changes to an enum
+  type, the size of the enum type must *NOT* have changed.
+
+
 * ``drop``
 
  Usage:
diff --git a/include/abg-suppression.h b/include/abg-suppression.h
index 9449d06d..d6283eb8 100644
--- a/include/abg-suppression.h
+++ b/include/abg-suppression.h
@@ -330,6 +330,12 @@ public:
   void
   set_changed_enumerator_names(const vector<string>&);
 
+  const vector<regex::regex_t_sptr>&
+  get_changed_enumerators_regexp() const;
+
+  void
+  set_changed_enumerators_regexp(const vector<regex::regex_t_sptr>&);
+
   virtual bool
   suppresses_diff(const diff* diff) const;
 
diff --git a/src/abg-suppression-priv.h b/src/abg-suppression-priv.h
index cf66a9f1..351c5965 100644
--- a/src/abg-suppression-priv.h
+++ b/src/abg-suppression-priv.h
@@ -585,6 +585,7 @@ class type_suppression::priv
   string				source_location_to_keep_regex_str_;
   mutable regex::regex_t_sptr		source_location_to_keep_regex_;
   mutable vector<string>		changed_enumerator_names_;
+  mutable vector<regex::regex_t_sptr>	changed_enumerators_regexp_;
 
   priv();
 
diff --git a/tests/data/Makefile.am b/tests/data/Makefile.am
index b3434da5..1632e2ab 100644
--- a/tests/data/Makefile.am
+++ b/tests/data/Makefile.am
@@ -1755,6 +1755,21 @@ test-diff-suppr/test39-public-headers-dir/test39-header-v0.h \
 test-diff-suppr/test39-public-headers-dir/test39-header-v1.h \
 test-diff-suppr/libtest40-enumerator-changes-v0.so \
 test-diff-suppr/libtest40-enumerator-changes-v1.so \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-1.suppr \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-2.suppr \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-3.suppr \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-4.suppr \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-5.suppr \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-0.txt \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-1.txt \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-2.txt \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-3.txt \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-4.txt \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-5.txt \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.c \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.c \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o \
+test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o \
 test-diff-suppr/libtest41-enumerator-changes-v0.so \
 test-diff-suppr/libtest41-enumerator-changes-v1.so \
 test-diff-suppr/test40-enumerator-changes-0.suppr \
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-1.suppr b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-1.suppr
new file mode 100644
index 00000000..cbe76ab8
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-1.suppr
@@ -0,0 +1,3 @@
+[suppress_type]
+  type_kind = enum
+  changed_enumerators_regexp = ^.*_LAST$
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-2.suppr b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-2.suppr
new file mode 100644
index 00000000..0ab63c10
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-2.suppr
@@ -0,0 +1,3 @@
+[suppress_type]
+  type_kind = enum
+  changed_enumerators_regexp = ^.*_MAX$
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-3.suppr b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-3.suppr
new file mode 100644
index 00000000..e8bb9117
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-3.suppr
@@ -0,0 +1,3 @@
+[suppress_type]
+  type_kind = enum
+  changed_enumerators_regexp = ^.*_LAST$, ^.*_MAX$
\ No newline at end of file
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-4.suppr b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-4.suppr
new file mode 100644
index 00000000..492dd336
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-4.suppr
@@ -0,0 +1,3 @@
+[suppress_type]
+  type_kind = enum
+  changed_enumerators_regexp = ^LAST_.*$
\ No newline at end of file
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-5.suppr b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-5.suppr
new file mode 100644
index 00000000..3ee5d407
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-5.suppr
@@ -0,0 +1,3 @@
+[suppress_type]
+  type_kind = enum
+  changed_enumerators_regexp = ^.*_LAST$, ^.*_MAX$, ^LAST_.*$
\ No newline at end of file
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-0.txt b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-0.txt
new file mode 100644
index 00000000..26435de3
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-0.txt
@@ -0,0 +1,29 @@
+Functions changes summary: 0 Removed, 3 Changed, 0 Added functions
+Variables changes summary: 0 Removed, 0 Changed, 0 Added variable
+
+3 functions with some indirect sub-type change:
+
+  [C] 'function void fun0(Enum0)' at test40.1-enumerator-changes-enumerator-changes-v0.c:25:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum0' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum0::ENUM0_E1' value '1'
+      1 enumerator change:
+        'Enum0::ENOM0_LAST' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:6:1
+
+  [C] 'function void fun1(Enum1)' at test40.1-enumerator-changes-enumerator-changes-v0.c:30:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum1' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum1::ENUM1_E1' value '1'
+      1 enumerator change:
+        'Enum1::ENUM1_MAX' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:13:1
+
+  [C] 'function void fun2(Enum2)' at test40.1-enumerator-changes-enumerator-changes-v0.c:35:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum2' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum2::ENUM2_E1' value '1'
+      1 enumerator change:
+        'Enum2::LAST_ENUM1_ENUMERATOR' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:20:1
+
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-1.txt b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-1.txt
new file mode 100644
index 00000000..ff415ac5
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-1.txt
@@ -0,0 +1,21 @@
+Functions changes summary: 0 Removed, 2 Changed (1 filtered out), 0 Added functions
+Variables changes summary: 0 Removed, 0 Changed, 0 Added variable
+
+2 functions with some indirect sub-type change:
+
+  [C] 'function void fun1(Enum1)' at test40.1-enumerator-changes-enumerator-changes-v0.c:30:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum1' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum1::ENUM1_E1' value '1'
+      1 enumerator change:
+        'Enum1::ENUM1_MAX' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:13:1
+
+  [C] 'function void fun2(Enum2)' at test40.1-enumerator-changes-enumerator-changes-v0.c:35:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum2' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum2::ENUM2_E1' value '1'
+      1 enumerator change:
+        'Enum2::LAST_ENUM1_ENUMERATOR' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:20:1
+
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-2.txt b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-2.txt
new file mode 100644
index 00000000..7e4093ca
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-2.txt
@@ -0,0 +1,21 @@
+Functions changes summary: 0 Removed, 2 Changed (1 filtered out), 0 Added functions
+Variables changes summary: 0 Removed, 0 Changed, 0 Added variable
+
+2 functions with some indirect sub-type change:
+
+  [C] 'function void fun0(Enum0)' at test40.1-enumerator-changes-enumerator-changes-v0.c:25:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum0' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum0::ENUM0_E1' value '1'
+      1 enumerator change:
+        'Enum0::ENOM0_LAST' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:6:1
+
+  [C] 'function void fun2(Enum2)' at test40.1-enumerator-changes-enumerator-changes-v0.c:35:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum2' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum2::ENUM2_E1' value '1'
+      1 enumerator change:
+        'Enum2::LAST_ENUM1_ENUMERATOR' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:20:1
+
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-3.txt b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-3.txt
new file mode 100644
index 00000000..9f4bbcb2
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-3.txt
@@ -0,0 +1,13 @@
+Functions changes summary: 0 Removed, 1 Changed (2 filtered out), 0 Added functions
+Variables changes summary: 0 Removed, 0 Changed, 0 Added variable
+
+1 function with some indirect sub-type change:
+
+  [C] 'function void fun2(Enum2)' at test40.1-enumerator-changes-enumerator-changes-v0.c:35:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum2' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum2::ENUM2_E1' value '1'
+      1 enumerator change:
+        'Enum2::LAST_ENUM1_ENUMERATOR' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:20:1
+
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-4.txt b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-4.txt
new file mode 100644
index 00000000..e09641c6
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-4.txt
@@ -0,0 +1,21 @@
+Functions changes summary: 0 Removed, 2 Changed (1 filtered out), 0 Added functions
+Variables changes summary: 0 Removed, 0 Changed, 0 Added variable
+
+2 functions with some indirect sub-type change:
+
+  [C] 'function void fun0(Enum0)' at test40.1-enumerator-changes-enumerator-changes-v0.c:25:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum0' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum0::ENUM0_E1' value '1'
+      1 enumerator change:
+        'Enum0::ENOM0_LAST' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:6:1
+
+  [C] 'function void fun1(Enum1)' at test40.1-enumerator-changes-enumerator-changes-v0.c:30:1 has some indirect sub-type changes:
+    parameter 1 of type 'enum Enum1' has sub-type changes:
+      type size hasn't changed
+      1 enumerator insertion:
+        'Enum1::ENUM1_E1' value '1'
+      1 enumerator change:
+        'Enum1::ENUM1_MAX' from value '1' to '2' at test40.1-enumerator-changes-enumerator-changes-v1.c:13:1
+
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-5.txt b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-5.txt
new file mode 100644
index 00000000..97239c74
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-5.txt
@@ -0,0 +1,3 @@
+Functions changes summary: 0 Removed, 0 Changed (3 filtered out), 0 Added functions
+Variables changes summary: 0 Removed, 0 Changed, 0 Added variable
+
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.c b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.c
new file mode 100644
index 00000000..7b32ee8b
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.c
@@ -0,0 +1,37 @@
+/**
+ * compile this with:
+ *   gcc -g -c test40.1-enumerator-changes-enumerator-changes-v0.c
+ */
+
+enum Enum0
+{
+  ENUM0_E0,
+  ENOM0_LAST
+};
+
+enum Enum1
+{
+  ENUM1_E0,
+  ENUM1_MAX
+};
+
+enum Enum2
+{
+  ENUM2_E0,
+  LAST_ENUM1_ENUMERATOR
+};
+
+void
+fun0(enum Enum0 p __attribute__((unused)))
+{
+}
+
+void
+fun1(enum Enum1 p __attribute__((unused)))
+{
+}
+
+void
+fun2(enum Enum2 p __attribute__((unused)))
+{
+}
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o
new file mode 100644
index 0000000000000000000000000000000000000000..8234f05d0e157a66a88be438cbe4a1f17c2fa01f
GIT binary patch
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.c b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.c
--- /dev/null
+++ b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.c
@@ -0,0 +1,40 @@
+/**
+ * compile this with:
+ *   gcc -g -c test40.1-enumerator-changes-enumerator-changes-v1.c
+ */
+
+enum Enum0
+{
+  ENUM0_E0,
+  ENUM0_E1,
+  ENOM0_LAST
+};
+
+enum Enum1
+{
+  ENUM1_E0,
+  ENUM1_E1,
+  ENUM1_MAX
+};
+
+enum Enum2
+{
+  ENUM2_E0,
+  ENUM2_E1,
+  LAST_ENUM1_ENUMERATOR
+};
+
+void
+fun0(enum Enum0 p __attribute__((unused)))
+{
+}
+
+void
+fun1(enum Enum1 p __attribute__((unused)))
+{
+}
+
+void
+fun2(enum Enum2 p __attribute__((unused)))
+{
+}
diff --git a/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o b/tests/data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o
new file mode 100644
index 0000000000000000000000000000000000000000..5438d75e9486777259484d9feec98fba7ff0f3f2
GIT binary patch
diff --git a/tests/test-diff-suppr.cc b/tests/test-diff-suppr.cc
--- a/tests/test-diff-suppr.cc
+++ b/tests/test-diff-suppr.cc
@@ -1836,6 +1836,66 @@ InOutSpec in_out_specs[] =
     "data/test-diff-suppr/test40-enumerator-changes-report-0.txt",
     "output/test-diff-suppr/test40-enumerator-changes-report-0.txt"
   },
+  {
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o",
+    "",
+    "",
+    "",
+    "--no-default-suppression",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-0.txt",
+    "output/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-0.txt"
+  },
+  {
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o",
+    "",
+    "",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-1.suppr",
+    "--no-default-suppression",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-1.txt",
+    "output/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-1.txt"
+  },
+  {
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o",
+    "",
+    "",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-2.suppr",
+    "--no-default-suppression",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-2.txt",
+    "output/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-2.txt"
+  },
+  {
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o",
+    "",
+    "",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-3.suppr",
+    "--no-default-suppression",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-3.txt",
+    "output/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-3.txt"
+  },
+  {
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o",
+    "",
+    "",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-4.suppr",
+    "--no-default-suppression",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-4.txt",
+    "output/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-4.txt"
+  },
+  {
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v0.o",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-v1.o",
+    "",
+    "",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-5.suppr",
+    "--no-default-suppression",
+    "data/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-5.txt",
+    "output/test-diff-suppr/test40.1-enumerator-changes-enumerator-changes-report-5.txt"
+  },
   {
     "data/test-diff-suppr/libtest41-enumerator-changes-v0.so",
     "data/test-diff-suppr/libtest41-enumerator-changes-v1.so",

diff --git a/src/abg-suppression.cc b/src/abg-suppression.cc
index 4ed42e82..22adfa8c 100644
--- a/src/abg-suppression.cc
+++ b/src/abg-suppression.cc
@@ -770,6 +770,28 @@ void
 type_suppression::set_changed_enumerator_names(const vector<string>& n)
 {priv_->changed_enumerator_names_ = n;}
 
+/// Getter of the vector of the regular expression strings for changed
+/// enumerators that are supposed to be suppressed. Note that this
+/// will be "valid" only if the type suppression has the
+/// 'type_kind = enum' property.
+///
+/// @return the vector of the regular expression strings that are
+/// supposed to match enumertor names to be suppressed.
+const vector<regex::regex_t_sptr>&
+type_suppression::get_changed_enumerators_regexp() const
+{return priv_->changed_enumerators_regexp_;}
+
+/// Setter of the vector of the regular expression strings for changed
+/// enumerators that are supposed to be suppressed. Note that this
+/// will be "valid" only if the type suppression has the
+/// 'type_kind = enum' property.
+///
+/// @param n the vector of the regular expression strings that are
+/// supposed to match enumertor names to be suppressed.
+void
+type_suppression::set_changed_enumerators_regexp(const vector<regex::regex_t_sptr>& n)
+{priv_->changed_enumerators_regexp_ = n;}
+
 /// Evaluate this suppression specification on a given diff node and
 /// say if the diff node should be suppressed or not.
 ///
@@ -996,9 +1018,12 @@ type_suppression::suppresses_diff(const diff* diff) const
       // ... and yet carries some changed enumerators!
       && !enum_dif->changed_enumerators().empty())
     {
-      // Make sure that all changed enumerators are listed in the
-      // vector of enumerator names returned by the
-      // get_changed_enumerator_names() member function.
+
+      // Make sure that all changed enumerators are either:
+      //  1. listed in the vector of enumerator names returned
+      //     by the get_changed_enumerator_names() member function
+      //  2. match a regular expression returned by the
+      //     get_changed_enumerators_regexp() member function
       bool matched = true;
       for (string_changed_enumerator_map::const_iterator i =
 	     enum_dif->changed_enumerators().begin();
@@ -1006,13 +1031,20 @@ type_suppression::suppresses_diff(const diff* diff) const
 	   ++i)
 	{
 	  matched &= true;
-	  if (std::find(get_changed_enumerator_names().begin(),
-			get_changed_enumerator_names().end(),
-			i->first) == get_changed_enumerator_names().end())
-	    {
-	      matched &= false;
-	      break;
-	    }
+	  if ((std::find(get_changed_enumerator_names().begin(),
+			 get_changed_enumerator_names().end(),
+			 i->first) == get_changed_enumerator_names().end())
+	     &&
+	      (std::find_if(get_changed_enumerators_regexp().begin(),
+			    get_changed_enumerators_regexp().end(),
+			    [&] (const regex_t_sptr& enum_regexp)
+		{
+		  return regex::match(enum_regexp, i->first);
+		}) == get_changed_enumerators_regexp().end()))
+	  {
+	    matched &= false;
+	    break;
+	  }
 	}
       if (!matched)
 	return false;
@@ -2154,6 +2186,34 @@ read_type_suppression(const ini::config::section& section)
 	changed_enumerator_names.push_back(p->get_value()->as_string());
     }
 
+  /// Support 'changed_enumerators_regexp = .*_foo, bar_[0-9]+, baz'
+  ///
+  /// If the current type is an enum and if it carries changed
+  /// enumerators that match regular expressions listed in the
+  /// changed_enumerators_regexp property value then it should be
+  /// suppressed.
+
+  ini::property_sptr changed_enumerators_regexp_prop =
+    section.find_property("changed_enumerators_regexp");
+
+  vector<regex_t_sptr> changed_enumerators_regexp;
+  if (changed_enumerators_regexp_prop)
+    {
+      if (ini::list_property_sptr p =
+	  is_list_property(changed_enumerators_regexp_prop))
+      {
+	for (string e : p->get_value()->get_content())
+	  changed_enumerators_regexp.push_back(regex::compile(e));
+      }
+      else if (ini::simple_property_sptr p =
+	       is_simple_property(changed_enumerators_regexp_prop))
+      {
+	changed_enumerators_regexp.push_back(
+	  regex::compile(p->get_value()->as_string())
+	);
+      }
+    }
+
   if (section.get_name() == "suppress_type")
     result.reset(new type_suppression(label_str, name_regex_str, name_str));
   else if (section.get_name() == "allow_type")
@@ -2217,6 +2277,10 @@ read_type_suppression(const ini::config::section& section)
       && !changed_enumerator_names.empty())
     result->set_changed_enumerator_names(changed_enumerator_names);
 
+  if (result->get_type_kind() == type_suppression::ENUM_TYPE_KIND
+      && !changed_enumerators_regexp.empty())
+    result->set_changed_enumerators_regexp(changed_enumerators_regexp);
+
   return result;
 }
 